<?php
if (! function_exists('besa_clear_header_layouts_transient')) {
    function besa_clear_header_layouts_transient($post_id) {
        delete_transient('besa_header_layouts_elementor');
    }

    add_action('save_post_tbay_header', 'besa_clear_header_layouts_transient');
    add_action('delete_post_tbay_header', 'besa_clear_header_layouts_transient');
    add_action('edit_post_tbay_header', 'besa_clear_header_layouts_transient');
}

if (! function_exists('besa_clear_footer_layouts_transient')) {
    function besa_clear_footer_layouts_transient($post_id) {
        delete_transient('besa_footer_layouts_elementor');
    }
    add_action('save_post_tbay_footer', 'besa_clear_footer_layouts_transient');
    add_action('delete_post_tbay_footer', 'besa_clear_footer_layouts_transient');
    add_action('edit_post_tbay_footer', 'besa_clear_footer_layouts_transient');
}

if ( ! function_exists( 'besa_clear_available_pages_transient' ) ) {
    function besa_clear_available_pages_transient($post_id) {
        delete_transient('besa_available_pages');
    }
    add_action('save_post_page', 'besa_clear_available_pages_transient');
    add_action('delete_post_page', 'besa_clear_available_pages_transient');
}

if (!function_exists('besa_clear_on_sale_products_transient')) {
    /**
     * Clear on-sale products transient when product stock, post, or sale price changes.
     *
     * @param int|WC_Product $product Product ID or object (depending on hook)
     */
    function besa_clear_on_sale_products_transient() {
        delete_transient('besa_on_sale_products');
    }

    // Hook into product post save
    add_action('save_post_product', 'besa_clear_on_sale_products_transient');
    add_action('delete_post_product', 'besa_clear_on_sale_products_transient');
    add_action('edit_post_product', 'besa_clear_on_sale_products_transient');
}

if (! function_exists('besa_clear_available_menus_transient')) {
    function besa_clear_available_menus_transient() {
        delete_transient('besa_available_menus');
        global $sitepress;
        $current_lang = apply_filters('wpml_current_language', null);
        delete_transient('besa_menus_wpml_' . $current_lang);
    }
    // Hook into menu creation
    add_action('wp_create_nav_menu', 'besa_clear_available_menus_transient');
    // Hook into menu deletion
    add_action('wp_delete_nav_menu', 'besa_clear_available_menus_transient');
}

if (! function_exists('besa_clear_product_categories_transient')) {
    // Function to delete transients for product categories
    function besa_clear_product_categories_transient($term_id, $tt_id, $taxonomy) {
        delete_transient('besa_product_categories_all');
    }
    add_action('created_product_cat', 'besa_clear_product_categories_transient', 10, 3);
    add_action('edited_product_cat', 'besa_clear_product_categories_transient', 10, 3);
    add_action('delete_product_cat', 'besa_clear_product_categories_transient', 10, 2);
}

if (! function_exists('besa_clear_menu_account_transients')) {
    function besa_clear_menu_account_transients($menu_id) {
        $menus = wp_get_nav_menus();
        foreach ($menus as $menu) {
            if ($menu->term_id == $menu_id) {
                $transient_key = 'besa_menu_account_' . md5($menu->slug);
                delete_transient($transient_key);
            }
        }
    }
    add_action('wp_update_nav_menu', 'besa_clear_menu_account_transients');
}

if (! function_exists('besa_clear_megamenu_cache')) {
    function besa_clear_megamenu_cache($post_id) {
        set_transient('besa_megamenu_cache_clear', true, 60);
    }
    add_action('save_post_tbay_megamenu', 'besa_clear_megamenu_cache');
    add_action('delete_post_tbay_megamenu', 'besa_clear_megamenu_cache');
    add_action('wp_trash_post_tbay_megamenu', 'besa_clear_megamenu_cache');
}

if (!function_exists('besa_clear_quickview_transient')) {
    /**
     * Delete quickview transient when product is updated.
     */
    function besa_clear_quickview_transient($product_id) {
        if (get_post_type($product_id) !== 'product' || get_post_status($product_id) === 'auto-draft') {
            return;
        }

        $cache_key = 'besa_quickview_' . $product_id;
        delete_transient($cache_key);
    }
    add_action('woocommerce_update_product', 'besa_clear_quickview_transient', 10, 1);
    add_action('save_post', 'besa_clear_quickview_transient', 10, 1);
}